export interface ConfigSaved {
    action: Action;
    app_key: string;
    app_name?: string;
    environment_key: string;
    metadata?: {
        [key: string]: any;
    };
    organization_key: string;
    space_key: string;
    [property: string]: any;
}
export declare enum Action {
    Added = "added",
    Cancelled = "cancelled",
    Deleted = "deleted",
    Installed = "installed",
    Updated = "updated"
}
export interface FlowStart {
    ai_model: string;
    ai_provider: string;
    app_key: string;
    app_name?: string;
    config_options: FlowStartConfigOptions;
    content_type_id: string;
    entry_id: string;
    environment_key: string;
    feature_id: string;
    organization_key: string;
    space_key: string;
    [property: string]: any;
}
export interface FlowStartConfigOptions {
    has_additional?: boolean;
    has_audience?: boolean;
    has_exclude?: boolean;
    has_include?: boolean;
    has_profile?: boolean;
    has_tone?: boolean;
    has_values?: boolean;
    [property: string]: any;
}
export interface GenerateClicked {
    ai_model: string;
    ai_provider: string;
    app_key: string;
    app_name?: string;
    config_options: GenerateClickedConfigOptions;
    content_generation_prompt?: string;
    content_type_id: string;
    entry_id: string;
    environment_key: string;
    feature_id: string;
    from_prompt?: boolean;
    organization_key: string;
    source_field?: string;
    space_key: string;
    target_locale?: string;
    [property: string]: any;
}
export interface GenerateClickedConfigOptions {
    has_additional?: boolean;
    has_audience?: boolean;
    has_exclude?: boolean;
    has_include?: boolean;
    has_profile?: boolean;
    has_tone?: boolean;
    has_values?: boolean;
    [property: string]: any;
}
export interface GeneratedContentEdited {
    ai_model: string;
    ai_provider: string;
    app_key: string;
    app_name?: string;
    config_options: GeneratedContentEditedConfigOptions;
    content_generation_prompt?: string;
    content_type_id: string;
    entry_id: string;
    environment_key: string;
    feature_id: string;
    from_prompt?: boolean;
    organization_key: string;
    source_locale?: string;
    space_key: string;
    target_locale?: string;
    [property: string]: any;
}
export interface GeneratedContentEditedConfigOptions {
    has_additional?: boolean;
    has_audience?: boolean;
    has_exclude?: boolean;
    has_include?: boolean;
    has_profile?: boolean;
    has_tone?: boolean;
    has_values?: boolean;
    [property: string]: any;
}
export interface RegenerationClicked {
    ai_model: string;
    ai_provider: string;
    app_key: string;
    app_name?: string;
    config_options?: RegenerationClickedConfigOptions;
    content_generation_prompt?: string;
    content_type_id: string;
    entry_id: string;
    environment_key: string;
    feature_id?: string;
    from_prompt?: boolean;
    organization_key: string;
    source_field?: string;
    space_key: string;
    target_locale?: string;
    [property: string]: any;
}
export interface RegenerationClickedConfigOptions {
    has_additional?: boolean;
    has_audience?: boolean;
    has_exclude?: boolean;
    has_include?: boolean;
    has_profile?: boolean;
    has_tone?: boolean;
    has_values?: boolean;
    [property: string]: any;
}
export interface SidebarRendered {
    ai_model: string;
    ai_provider: string;
    app_key: string;
    app_name?: string;
    config_options: SidebarRenderedConfigOptions;
    content_type_id: string;
    entry_id: string;
    environment_key: string;
    organization_key: string;
    space_key: string;
    [property: string]: any;
}
export interface SidebarRenderedConfigOptions {
    has_additional?: boolean;
    has_audience?: boolean;
    has_exclude?: boolean;
    has_include?: boolean;
    has_profile?: boolean;
    has_tone?: boolean;
    has_values?: boolean;
    [property: string]: any;
}
import { ErrorObject } from 'ajv';
import type { AnalyticsSnippet, Analytics, AnalyticsBrowser, Options } from '@segment/analytics-next';
declare global {
    interface Window {
        analytics: AnalyticsSnippet;
    }
}
type AnyAnalytics = AnalyticsSnippet | Analytics | AnalyticsBrowser;
export type Callback = () => void;
export type ViolationHandler = (message: Record<string, any>, violations: ErrorObject[]) => void;
export declare const defaultValidationErrorHandler: ViolationHandler;
export interface TypewriterOptions {
    analytics?: AnyAnalytics;
    onViolation?: ViolationHandler;
}
export declare function setTypewriterOptions(options: TypewriterOptions): void;
export declare function configSaved(props: ConfigSaved, options?: Options, callback?: Callback): void;
export declare function flowStart(props: FlowStart, options?: Options, callback?: Callback): void;
export declare function generateClicked(props: GenerateClicked, options?: Options, callback?: Callback): void;
export declare function generatedContentEdited(props: GeneratedContentEdited, options?: Options, callback?: Callback): void;
export declare function regenerationClicked(props: RegenerationClicked, options?: Options, callback?: Callback): void;
export declare function sidebarRendered(props: SidebarRendered, options?: Options, callback?: Callback): void;
declare const _default: {
    setTypewriterOptions: typeof setTypewriterOptions;
    configSaved: typeof configSaved;
    flowStart: typeof flowStart;
    generateClicked: typeof generateClicked;
    generatedContentEdited: typeof generatedContentEdited;
    regenerationClicked: typeof regenerationClicked;
    sidebarRendered: typeof sidebarRendered;
};
export default _default;
